@@ -369,12 +369,13 @@ bool TestEGLError(const char* pszLocation)
 }
 
 void maemoGLinit(){
+
 	printf ("GL init\n");
 
 	EGLint numConfigs;
 	EGLint majorVersion;
 	EGLint minorVersion;
-//#if defined(USE_X11)
+#if defined(USE_X11)
 	enum
 	{
 	_NET_WM_STATE_REMOVE =0,
@@ -386,10 +387,10 @@ void maemoGLinit(){
 	XSetWindowAttributes	sWA;
 	unsigned int		    ui32Mask;
 	int			            i32Depth;
-//#endif
+#endif
 	
 	EGLint *attribList = NULL;
-	if (use_fsaa)
+	if (use_fsaa==1)
 	{
 		printf( "GLES: Using Full Scene Antialiasing\n" );
 		attribList = attrib_list_fsaa;
@@ -399,10 +400,15 @@ void maemoGLinit(){
 		attribList = attrib_list;
 	}
 
+#if defined(USE_X11)
 	pandora_driver_mode = MODE_X11; // TODO make configurable
-
+#else
+	pandora_driver_mode = MODE_RAW; // TODO make configurable
+#endif
 	
-
+          
+#if defined(USE_X11)
+        //case MODE_X11:
             // Initializes the display and screen
             x11Display = XOpenDisplay( ":0" );
             if (!x11Display)
@@ -435,6 +441,10 @@ void maemoGLinit(){
                                         0, CopyFromParent, InputOutput, CopyFromParent, ui32Mask, &sWA);
 
             // Make the window viewable and flush the output buffer.
+									XWMHints hints;
+hints.input = True;
+hints.flags = InputHint;
+XSetWMHints(x11Display, x11Window, &hints);
             XMapWindow(x11Display, x11Window);
             XFlush(x11Display);
 
@@ -457,7 +467,11 @@ void maemoGLinit(){
             XSendEvent(x11Display, DefaultRootWindow(x11Display), False, SubstructureRedirectMask | SubstructureNotifyMask, &xev);
 
             display = eglGetDisplay( (EGLNativeDisplayType)x11Display );
-          
+#else
+		 display = eglGetDisplay( (EGLNativeDisplayType)0 );	
+#endif
+
+
 	if( display == EGL_NO_DISPLAY )
 	{
 		printf( "GLES EGL Error: GL No Display\n" );
@@ -480,8 +494,11 @@ void maemoGLinit(){
 	}
 
 
+#if defined(USE_X11)
             surface = eglCreateWindowSurface( display, config, (EGLNativeWindowType)x11Window, NULL );
-  	
+#else
+            surface = eglCreateWindowSurface( display, config, (EGLNativeDisplayType)0, NULL );
+#endif
 
     eglMakeCurrent( display, surface, surface, context );
     if (!TestEGLError("eglMakeCurrent"))
@@ -505,6 +522,7 @@ int GLinitialize()
  if(bWindowMode) ReleaseDC(hWWindow,dcGlobal);         // win mode: release dc again
 #endif
 #ifdef MAEMO_CHANGES
+	 if (!iResX||!iResY)GPUopen(0,"PCSX",NULL);
 	 maemoGLinit();
 #endif
  //----------------------------------------------------// 
